@@ -3,6 +3,9 @@ import Vision
 
 
 class TestVNGeneratePersonSegmentationRequest(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(Vision.VNGeneratePersonSegmentationRequestQualityLevel)
+
     def test_constants(self):
         self.assertEqual(
             Vision.VNGeneratePersonSegmentationRequestQualityLevelAccurate, 0
